/* SMG2 serial windows reader; (C)2012-2014 Jaroslav Fojtik, Licence LGPL. */


#include <stdio.h>          /* Standard input/output definitions */

#ifdef _WIN32
  #include <windows.h>
#else
  #include <termios.h> 
#endif

#include "serial.h"


static const char *Config = "baud=115200 parity=N data=8 stop=1";



T_COM open_serial(const char *ncom)
{
T_COM H_Com;
unsigned long MErr;
COMSTAT MCStat;

  H_Com = CreateFile(ncom, GENERIC_READ|GENERIC_WRITE, 0, NULL, OPEN_EXISTING, 0, NULL);
  if(H_Com == INVALID_HANDLE_VALUE)
  {
    ClearCommError(H_Com,&MErr,&MCStat);
    return(NULL);
 }

  return H_Com;
}


int set_serial_line(T_COM HCom, int baud)
{
DCB Dcb;
COMMTIMEOUTS MCTmouts;

  if (!SetupComm(HCom,6000,1024)) return(-2);
  memset(&Dcb,0,sizeof(DCB));
  Dcb.DCBlength = sizeof(DCB);
  if (!BuildCommDCB(Config,&Dcb)) return(-3);
  if (baud) Dcb.BaudRate=baud;
  if (!SetCommState(HCom,&Dcb)) return(-4);
  MCTmouts.ReadIntervalTimeout=0;
  MCTmouts.ReadTotalTimeoutMultiplier=1;
  MCTmouts.ReadTotalTimeoutConstant=10;
  MCTmouts.WriteTotalTimeoutMultiplier=2;
  MCTmouts.WriteTotalTimeoutConstant=100;
  if (!SetCommTimeouts(HCom,&MCTmouts)) return(-5);
  if (!PurgeComm(HCom,PURGE_RXCLEAR)) return(-6);  

  return 0;
}


int restore_serial_line(T_COM fd)
{
	/* restore the old port settings */
  //tcsetattr(fd, TCSANOW, stored_tio);
  return 0;
}


void close_serial_line(T_COM HCom)
{
  CloseHandle(HCom);
}


int write_serial(T_COM HCom, const char *DATA, unsigned size)
{
int scnt;
  if(!WriteFile(HCom, DATA, size, &scnt, NULL)) return -1;
  return scnt;
}


int read_serial(T_COM HCom, char *DATA, unsigned size)
{
int scnt;
  if(!ReadFile(HCom, DATA, size, &scnt, NULL)) return -1;
  return scnt;
}



